@@ -5,9 +5,7 @@ use List::Util 'first';
 use Mojo::Loader ();
 use Mojo::Util 'camelize';
 
-our $VERSION = '0.05';
-
-has models => sub { {} };
+our $VERSION = '0.06';
 
 sub register {
   my ($plugin, $app, $conf) = @_;
@@ -19,11 +17,11 @@ sub register {
     model => sub {
       my ($self, $name) = @_;
 
-      $name = $conf->{default} unless defined($name);
+      $name = $conf->{default} unless defined $name;
       $name = camelize($name) if $name =~ /^[a-z]/;
 
       my $model;
-      return $model if $model = $plugin->models->{$name};
+      return $model if $model = $plugin->{models}{$name};
 
       for my $class (map { "${_}::$name" } @$ns) {
         next unless _load_class($class);
@@ -33,9 +31,9 @@ sub register {
           next;
         }
 
-        $model =
-          $class->new(ref($conf->{params}{$name}) eq 'HASH' ? %{$conf->{params}{$name}} : (), app => $app);
-        $plugin->models->{$name} = $model;
+        my $params = $conf->{params}{$name};
+        $model = $class->new(ref $params eq 'HASH' ? %$params : (), app => $app);
+        $plugin->{models}{$name} = $model;
         return $model;
       }
 
